#!/bin/bash
 
# Packager : Markus Muttilainen <stillborn.zenwalk@gmail.com>
#
# Packaging date : 13/03/2010
#
#package			: wvdial
#homepage			: http://alumnit.ca/wiki/index.php?page=WvDial
#source location                : http://wvstreams.googlecode.com/files/wvdial-1.61.tar.gz
#dependency: 
set -e -u -x
#> log
(

softname='wvdial'
softversion='1.61'
zenver='64.2'
arch='i486'
cpu='i686'
numjobs='-j3'

#>

buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.gz"
package="$softname-$softversion-$arch-$zenver"
dest="$buildir/$package"
source=http://wvstreams.googlecode.com/files/wvdial-1.61.tar.gz
sourcetemplate=http://zenwalk.pinguix.com/user-accounts/stillborn/wvdial

#>

rm -rf $dest
mkdir -p $dest/{install,usr/{doc/$softname-$softversion,src/$softname-$softversion}}

#> prepare slack-desc
cat << EOF > $dest/install/slack-desc 
      |-----handy-ruler------------------------------------------------------|
wvdial: wvdial (ppp dialer app)
wvdial:
wvdial: Wvdial is a program that makes it easy to connect your Linux 
wvdial: workstation to the Internet. It will automatically detect your
wvdial: modem, and it can log into almost any Internet provider's
wvdial: server without any special configuration.
wvdial: 
wvdial: http://alumnit.ca/wiki/index.php?page=WvDial
wvdial:
wvdial:
wvdial:
EOF

#> check for sources
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

#> extract sources
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
cd $buildir
tar zxvf $srcpkg
cd $src

#> Add DESTDIR support to the Makefile
CFLAGS="-O2 -march=$arch -mtune=$cpu" \
CXXFLAGS="-O2 -march=$arch -mtune=$cpu" \
./configure
patch -u Makefile $buildir/Makefile.diff
make prefix=/usr MANDIR=/usr/man
make install prefix=/usr MANDIR=/usr/man  DESTDIR=$dest

#> add docs ...
(cd $src
cp -av \
      CHANGES COPYING.LIB ChangeLog FAQ README TODO MENUS \
$dest/usr/doc/$softname-$softversion
)

#> Strip executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs -r strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs -r strip --strip-unneeded 2> /dev/null
)

#> Compress and if needed symlink the man pages:
( cd $dest/usr/man
  find . -type f -exec gzip -9 {} \;
  for i in $( find . -type l ) ; do ln -s $( readlink $i ).gz $i.gz ; rm $i ; done
)

#> Add a sample config file, and don't clobber any of them on upgrades
(
cd $buildir
cp -v wvdial.conf $dest/etc/wvdial.conf.new
mv $dest/etc/ppp/peers/wvdial-pipe $dest/etc/ppp/peers/wvdial-pipe.new
mv $dest/etc/ppp/peers/wvdial $dest/etc/ppp/peers/wvdial.new
)

#> store buildscript 
(
cp -v $buildir/{"build-$softname.sh","Makefile.diff","wvdial.conf"} $dest/usr/src/$softname-$softversion
)

#> fix permissions
(
chown -R root:root $dest
cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
)

#> helperline
(cd $dest;find . -printf "%y %m %u:%g %p %l\n") >$buildir/pkgtree.log

#> do the actual zenwalk package
(
cd $dest
makepkg -l y -c n $dest.txz
)

#> prepare .src .dep .md5
cd $buildir
md5sum $package.txz > $package.md5
depfinder $package.txz > $package.dep
echo $sourcetemplate/build-$softname.sh > $package.src
echo $source >> $package.src
echo $sourcetemplate/Makefile.diff >> $package.src
echo $sourcetemplate/wvdial.conf >> $package.src
#>

rm -rf $src
rm -rf $dest


#> log
) 2>&1 | tee wvdial-build.log.txt
